Class: Google::Apis::DatamigrationV1beta1::ConnectionProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1beta1/classes.rb,
lib/google/apis/datamigration_v1beta1/representations.rb,
lib/google/apis/datamigration_v1beta1/representations.rb

Overview

A connection profile definition.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConnectionProfile

Returns a new instance of ConnectionProfile.



456
457
458
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 456

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cloudsqlGoogle::Apis::DatamigrationV1beta1::CloudSqlConnectionProfile

Specifies required connection parameters, and, optionally, the parameters required to create a Cloud SQL destination database instance. Corresponds to the JSON property cloudsql



396
397
398
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 396

def cloudsql
  @cloudsql
end

#create_timeString

Output only. The timestamp when the resource was created. A timestamp in RFC3339 UTC "Zulu" format, accurate to nanoseconds. Example: "2014-10-02T15:01: 23.045123456Z". Corresponds to the JSON property createTime

Returns:

  • (String)


403
404
405
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 403

def create_time
  @create_time
end

#display_nameString

The connection profile display name. Corresponds to the JSON property displayName

Returns:

  • (String)


408
409
410
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 408

def display_name
  @display_name
end

#errorGoogle::Apis::DatamigrationV1beta1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



418
419
420
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 418

def error
  @error
end

#labelsHash<String,String>

The resource labels for connection profile to use to annotate any related underlying resources such as Compute Engine VMs. An object containing a list of "key": "value" pairs. Example: "name": "wrench", "mass": "1.3kg", "count" : "3". Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


426
427
428
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 426

def labels
  @labels
end

#mysqlGoogle::Apis::DatamigrationV1beta1::MySqlConnectionProfile

Specifies connection parameters required specifically for MySQL databases. Corresponds to the JSON property mysql



431
432
433
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 431

def mysql
  @mysql
end

#nameString

The name of this connection profile resource in the form of projects/project/ locations/location/connectionProfiles/connectionProfile. Corresponds to the JSON property name

Returns:

  • (String)


437
438
439
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 437

def name
  @name
end

#providerString

The database provider. Corresponds to the JSON property provider

Returns:

  • (String)


442
443
444
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 442

def provider
  @provider
end

#stateString

The current connection profile state (e.g. DRAFT, READY, or FAILED). Corresponds to the JSON property state

Returns:

  • (String)


447
448
449
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 447

def state
  @state
end

#update_timeString

Output only. The timestamp when the resource was last updated. A timestamp in RFC3339 UTC "Zulu" format, accurate to nanoseconds. Example: "2014-10-02T15:01: 23.045123456Z". Corresponds to the JSON property updateTime

Returns:

  • (String)


454
455
456
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 454

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



461
462
463
464
465
466
467
468
469
470
471
472
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 461

def update!(**args)
  @cloudsql = args[:cloudsql] if args.key?(:cloudsql)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @error = args[:error] if args.key?(:error)
  @labels = args[:labels] if args.key?(:labels)
  @mysql = args[:mysql] if args.key?(:mysql)
  @name = args[:name] if args.key?(:name)
  @provider = args[:provider] if args.key?(:provider)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end