Class: Google::Apis::DatamigrationV1beta1::Help
- Inherits:
-
Object
- Object
- Google::Apis::DatamigrationV1beta1::Help
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamigration_v1beta1/classes.rb,
lib/google/apis/datamigration_v1beta1/representations.rb,
lib/google/apis/datamigration_v1beta1/representations.rb
Overview
Provides links to documentation or for performing an out of band action. For example, if a quota check failed with an error indicating the calling project hasn't enabled the accessed service, this can contain a URL pointing directly to the right place in the developer console to flip the bit.
Instance Attribute Summary collapse
-
#links ⇒ Array<Google::Apis::DatamigrationV1beta1::Link>
URL(s) pointing to additional information on handling the current error.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Help
constructor
A new instance of Help.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Help
Returns a new instance of Help.
810 811 812 |
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 810 def initialize(**args) update!(**args) end |
Instance Attribute Details
#links ⇒ Array<Google::Apis::DatamigrationV1beta1::Link>
URL(s) pointing to additional information on handling the current error.
Corresponds to the JSON property links
808 809 810 |
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 808 def links @links end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
815 816 817 |
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 815 def update!(**args) @links = args[:links] if args.key?(:links) end |