Class: Google::Apis::DatamigrationV1beta1::LocalizedMessage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1beta1/classes.rb,
lib/google/apis/datamigration_v1beta1/representations.rb,
lib/google/apis/datamigration_v1beta1/representations.rb

Overview

Provides a localized error message that is safe to return to the user which can be attached to an RPC error.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LocalizedMessage

Returns a new instance of LocalizedMessage.



984
985
986
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 984

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#localeString

The locale used following the specification defined at https://www.rfc-editor. org/rfc/bcp/bcp47.txt. Examples are: "en-US", "fr-CH", "es-MX" Corresponds to the JSON property locale

Returns:

  • (String)


977
978
979
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 977

def locale
  @locale
end

#messageString

The localized error message in the above locale. Corresponds to the JSON property message

Returns:

  • (String)


982
983
984
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 982

def message
  @message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



989
990
991
992
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 989

def update!(**args)
  @locale = args[:locale] if args.key?(:locale)
  @message = args[:message] if args.key?(:message)
end