Class: Google::Apis::DatamigrationV1beta1::MigrationJob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1beta1/classes.rb,
lib/google/apis/datamigration_v1beta1/representations.rb,
lib/google/apis/datamigration_v1beta1/representations.rb

Overview

Represents a Database Migration Service migration job object.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MigrationJob

Returns a new instance of MigrationJob.



1166
1167
1168
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1166

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The timestamp when the migration job resource was created. A timestamp in RFC3339 UTC "Zulu" format, accurate to nanoseconds. Example: " 2014-10-02T15:01:23.045123456Z". Corresponds to the JSON property createTime

Returns:

  • (String)


1051
1052
1053
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1051

def create_time
  @create_time
end

#destinationString

Required. The resource name (URI) of the destination connection profile. Corresponds to the JSON property destination

Returns:

  • (String)


1056
1057
1058
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1056

def destination
  @destination
end

#destination_databaseGoogle::Apis::DatamigrationV1beta1::DatabaseType

A message defining the database engine and provider. Corresponds to the JSON property destinationDatabase



1061
1062
1063
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1061

def destination_database
  @destination_database
end

#display_nameString

The migration job display name. Corresponds to the JSON property displayName

Returns:

  • (String)


1066
1067
1068
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1066

def display_name
  @display_name
end

#dump_pathString

The path to the dump file in Google Cloud Storage, in the format: (gs://[ BUCKET_NAME]/[OBJECT_NAME]). Corresponds to the JSON property dumpPath

Returns:

  • (String)


1072
1073
1074
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1072

def dump_path
  @dump_path
end

#durationString

Output only. The duration of the migration job (in seconds). A duration in seconds with up to nine fractional digits, terminated by 's'. Example: "3.5s". Corresponds to the JSON property duration

Returns:

  • (String)


1078
1079
1080
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1078

def duration
  @duration
end

#end_timeString

Output only. If the migration job is completed, the time when it was completed. Corresponds to the JSON property endTime

Returns:

  • (String)


1083
1084
1085
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1083

def end_time
  @end_time
end

#errorGoogle::Apis::DatamigrationV1beta1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



1093
1094
1095
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1093

def error
  @error
end

#labelsHash<String,String>

The resource labels for migration job to use to annotate any related underlying resources such as Compute Engine VMs. An object containing a list of "key": "value" pairs. Example: "name": "wrench", "mass": "1.3kg", "count" : "3". Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1101
1102
1103
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1101

def labels
  @labels
end

#nameString

The name (URI) of this migration job resource, in the form of: projects/ project/locations/location/migrationJobs/migrationJob. Corresponds to the JSON property name

Returns:

  • (String)


1107
1108
1109
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1107

def name
  @name
end

#phaseString

Output only. The current migration job phase. Corresponds to the JSON property phase

Returns:

  • (String)


1112
1113
1114
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1112

def phase
  @phase
end

#reverse_ssh_connectivityGoogle::Apis::DatamigrationV1beta1::ReverseSshConnectivity

The details needed to configure a reverse SSH tunnel between the source and destination databases. These details will be used when calling the generateSshScript method (see https://cloud.google.com/database-migration/docs/ reference/rest/v1beta1/projects.locations.migrationJobs/generateSshScript) to produce the script that will help set up the reverse SSH tunnel, and to set up the VPC peering between the Cloud SQL private network and the VPC. Corresponds to the JSON property reverseSshConnectivity



1122
1123
1124
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1122

def reverse_ssh_connectivity
  @reverse_ssh_connectivity
end

#sourceString

Required. The resource name (URI) of the source connection profile. Corresponds to the JSON property source

Returns:

  • (String)


1127
1128
1129
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1127

def source
  @source
end

#source_databaseGoogle::Apis::DatamigrationV1beta1::DatabaseType

A message defining the database engine and provider. Corresponds to the JSON property sourceDatabase



1132
1133
1134
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1132

def source_database
  @source_database
end

#stateString

The current migration job state. Corresponds to the JSON property state

Returns:

  • (String)


1137
1138
1139
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1137

def state
  @state
end

#static_ip_connectivityGoogle::Apis::DatamigrationV1beta1::StaticIpConnectivity

The source database will allow incoming connections from the destination database's public IP. You can retrieve the Cloud SQL instance's public IP from the Cloud SQL console or using Cloud SQL APIs. No additional configuration is required. Corresponds to the JSON property staticIpConnectivity



1145
1146
1147
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1145

def static_ip_connectivity
  @static_ip_connectivity
end

#typeString

Required. The migration job type. Corresponds to the JSON property type

Returns:

  • (String)


1150
1151
1152
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1150

def type
  @type
end

#update_timeString

Output only. The timestamp when the migration job resource was last updated. A timestamp in RFC3339 UTC "Zulu" format, accurate to nanoseconds. Example: " 2014-10-02T15:01:23.045123456Z". Corresponds to the JSON property updateTime

Returns:

  • (String)


1157
1158
1159
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1157

def update_time
  @update_time
end

#vpc_peering_connectivityGoogle::Apis::DatamigrationV1beta1::VpcPeeringConnectivity

The details of the VPC where the source database is located in Google Cloud. We will use this information to set up the VPC peering connection between Cloud SQL and this VPC. Corresponds to the JSON property vpcPeeringConnectivity



1164
1165
1166
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1164

def vpc_peering_connectivity
  @vpc_peering_connectivity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
1190
1191
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1171

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @destination = args[:destination] if args.key?(:destination)
  @destination_database = args[:destination_database] if args.key?(:destination_database)
  @display_name = args[:display_name] if args.key?(:display_name)
  @dump_path = args[:dump_path] if args.key?(:dump_path)
  @duration = args[:duration] if args.key?(:duration)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error = args[:error] if args.key?(:error)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @phase = args[:phase] if args.key?(:phase)
  @reverse_ssh_connectivity = args[:reverse_ssh_connectivity] if args.key?(:reverse_ssh_connectivity)
  @source = args[:source] if args.key?(:source)
  @source_database = args[:source_database] if args.key?(:source_database)
  @state = args[:state] if args.key?(:state)
  @static_ip_connectivity = args[:static_ip_connectivity] if args.key?(:static_ip_connectivity)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
  @vpc_peering_connectivity = args[:vpc_peering_connectivity] if args.key?(:vpc_peering_connectivity)
end