Class: Google::Apis::DatamigrationV1beta1::MigrationJobVerificationError

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1beta1/classes.rb,
lib/google/apis/datamigration_v1beta1/representations.rb,
lib/google/apis/datamigration_v1beta1/representations.rb

Overview

Error message of a verification Migration job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MigrationJobVerificationError

Returns a new instance of MigrationJobVerificationError.



1214
1215
1216
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1214

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_codeString

Output only. An instance of ErrorCode specifying the error that occurred. Corresponds to the JSON property errorCode

Returns:

  • (String)


1201
1202
1203
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1201

def error_code
  @error_code
end

#error_detail_messageString

Output only. A specific detailed error message, if supplied by the engine. Corresponds to the JSON property errorDetailMessage

Returns:

  • (String)


1206
1207
1208
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1206

def error_detail_message
  @error_detail_message
end

#error_messageString

Output only. A formatted message with further details about the error and a CTA. Corresponds to the JSON property errorMessage

Returns:

  • (String)


1212
1213
1214
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1212

def error_message
  @error_message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1219
1220
1221
1222
1223
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1219

def update!(**args)
  @error_code = args[:error_code] if args.key?(:error_code)
  @error_detail_message = args[:error_detail_message] if args.key?(:error_detail_message)
  @error_message = args[:error_message] if args.key?(:error_message)
end