Class: Google::Apis::DatamigrationV1beta1::QuotaFailure
- Inherits:
-
Object
- Object
- Google::Apis::DatamigrationV1beta1::QuotaFailure
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamigration_v1beta1/classes.rb,
lib/google/apis/datamigration_v1beta1/representations.rb,
lib/google/apis/datamigration_v1beta1/representations.rb
Overview
Describes how a quota check failed. For example if a daily limit was exceeded
for the calling project, a service could respond with a QuotaFailure detail
containing the project id and the description of the quota limit that was
exceeded. If the calling project hasn't enabled the service in the developer
console, then a service could respond with the project id and set
service_disabled to true. Also see RetryInfo and Help types for other details
about handling a quota failure.
Instance Attribute Summary collapse
-
#violations ⇒ Array<Google::Apis::DatamigrationV1beta1::QuotaFailureViolation>
Describes all quota violations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QuotaFailure
constructor
A new instance of QuotaFailure.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QuotaFailure
Returns a new instance of QuotaFailure.
1530 1531 1532 |
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1530 def initialize(**args) update!(**args) end |
Instance Attribute Details
#violations ⇒ Array<Google::Apis::DatamigrationV1beta1::QuotaFailureViolation>
Describes all quota violations.
Corresponds to the JSON property violations
1528 1529 1530 |
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1528 def violations @violations end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1535 1536 1537 |
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1535 def update!(**args) @violations = args[:violations] if args.key?(:violations) end |