Class: Google::Apis::DatamigrationV1beta1::ReverseSshConnectivity

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1beta1/classes.rb,
lib/google/apis/datamigration_v1beta1/representations.rb,
lib/google/apis/datamigration_v1beta1/representations.rb

Overview

The details needed to configure a reverse SSH tunnel between the source and destination databases. These details will be used when calling the generateSshScript method (see https://cloud.google.com/database-migration/docs/ reference/rest/v1beta1/projects.locations.migrationJobs/generateSshScript) to produce the script that will help set up the reverse SSH tunnel, and to set up the VPC peering between the Cloud SQL private network and the VPC.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReverseSshConnectivity

Returns a new instance of ReverseSshConnectivity.



1792
1793
1794
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1792

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#vmString

The name of the virtual machine (Compute Engine) used as the bastion server for the SSH tunnel. Corresponds to the JSON property vm

Returns:

  • (String)


1773
1774
1775
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1773

def vm
  @vm
end

#vm_ipString

Required. The IP of the virtual machine (Compute Engine) used as the bastion server for the SSH tunnel. Corresponds to the JSON property vmIp

Returns:

  • (String)


1779
1780
1781
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1779

def vm_ip
  @vm_ip
end

#vm_portFixnum

Required. The forwarding port of the virtual machine (Compute Engine) used as the bastion server for the SSH tunnel. Corresponds to the JSON property vmPort

Returns:

  • (Fixnum)


1785
1786
1787
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1785

def vm_port
  @vm_port
end

#vpcString

The name of the VPC to peer with the Cloud SQL private network. Corresponds to the JSON property vpc

Returns:

  • (String)


1790
1791
1792
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1790

def vpc
  @vpc
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1797
1798
1799
1800
1801
1802
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1797

def update!(**args)
  @vm = args[:vm] if args.key?(:vm)
  @vm_ip = args[:vm_ip] if args.key?(:vm_ip)
  @vm_port = args[:vm_port] if args.key?(:vm_port)
  @vpc = args[:vpc] if args.key?(:vpc)
end