Class: Google::Apis::DatamigrationV1beta1::VmCreationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1beta1/classes.rb,
lib/google/apis/datamigration_v1beta1/representations.rb,
lib/google/apis/datamigration_v1beta1/representations.rb

Overview

VM creation configuration message

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VmCreationConfig

Returns a new instance of VmCreationConfig.



2156
2157
2158
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 2156

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#subnetString

The subnet name the vm needs to be created in. Corresponds to the JSON property subnet

Returns:

  • (String)


2144
2145
2146
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 2144

def subnet
  @subnet
end

#vm_machine_typeString

Required. VM instance machine type to create. Corresponds to the JSON property vmMachineType

Returns:

  • (String)


2149
2150
2151
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 2149

def vm_machine_type
  @vm_machine_type
end

#vm_zoneString

The Google Cloud Platform zone to create the VM in. Corresponds to the JSON property vmZone

Returns:

  • (String)


2154
2155
2156
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 2154

def vm_zone
  @vm_zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2161
2162
2163
2164
2165
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 2161

def update!(**args)
  @subnet = args[:subnet] if args.key?(:subnet)
  @vm_machine_type = args[:vm_machine_type] if args.key?(:vm_machine_type)
  @vm_zone = args[:vm_zone] if args.key?(:vm_zone)
end