Class: Google::Apis::DatamigrationV1beta1::VpcPeeringConnectivity
- Inherits:
-
Object
- Object
- Google::Apis::DatamigrationV1beta1::VpcPeeringConnectivity
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamigration_v1beta1/classes.rb,
lib/google/apis/datamigration_v1beta1/representations.rb,
lib/google/apis/datamigration_v1beta1/representations.rb
Overview
The details of the VPC where the source database is located in Google Cloud. We will use this information to set up the VPC peering connection between Cloud SQL and this VPC.
Instance Attribute Summary collapse
-
#vpc ⇒ String
The name of the VPC network to peer with the Cloud SQL private network.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VpcPeeringConnectivity
constructor
A new instance of VpcPeeringConnectivity.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VpcPeeringConnectivity
Returns a new instance of VpcPeeringConnectivity.
2198 2199 2200 |
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 2198 def initialize(**args) update!(**args) end |
Instance Attribute Details
#vpc ⇒ String
The name of the VPC network to peer with the Cloud SQL private network.
Corresponds to the JSON property vpc
2196 2197 2198 |
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 2196 def vpc @vpc end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2203 2204 2205 |
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 2203 def update!(**args) @vpc = args[:vpc] if args.key?(:vpc) end |