Class: Google::Apis::DatamigrationV1beta1::CloudSqlSettings
- Inherits:
-
Object
- Object
- Google::Apis::DatamigrationV1beta1::CloudSqlSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamigration_v1beta1/classes.rb,
lib/google/apis/datamigration_v1beta1/representations.rb,
lib/google/apis/datamigration_v1beta1/representations.rb
Overview
Settings for creating a Cloud SQL database instance.
Instance Attribute Summary collapse
-
#activation_policy ⇒ String
The activation policy specifies when the instance is activated; it is applicable only when the instance state is 'RUNNABLE'.
-
#auto_storage_increase ⇒ Boolean
(also: #auto_storage_increase?)
[default: ON] If you enable this setting, Cloud SQL checks your available storage every 30 seconds.
-
#data_disk_size_gb ⇒ Fixnum
The storage capacity available to the database, in GB.
-
#data_disk_type ⇒ String
The type of storage:
PD_SSD(default) orPD_HDD. -
#database_flags ⇒ Hash<String,String>
The database flags passed to the Cloud SQL instance at startup.
-
#database_version ⇒ String
The database engine type and version.
-
#ip_config ⇒ Google::Apis::DatamigrationV1beta1::SqlIpConfig
IP Management configuration.
-
#root_password ⇒ String
Input only.
-
#root_password_set ⇒ Boolean
(also: #root_password_set?)
Output only.
-
#source_id ⇒ String
The Database Migration Service source connection profile ID, in the format:
projects/my_project_name/locations/us-central1/connectionProfiles/ connection_profile_IDCorresponds to the JSON propertysourceId. -
#storage_auto_resize_limit ⇒ Fixnum
The maximum size to which storage capacity can be automatically increased.
-
#tier ⇒ String
The tier (or machine type) for this instance, for example:
db-n1-standard-1( MySQL instances). -
#user_labels ⇒ Hash<String,String>
The resource labels for a Cloud SQL instance to use to annotate any related underlying resources such as Compute Engine VMs.
-
#zone ⇒ String
The Google Cloud Platform zone where your Cloud SQL database instance is located.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CloudSqlSettings
constructor
A new instance of CloudSqlSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CloudSqlSettings
Returns a new instance of CloudSqlSettings.
365 366 367 |
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 365 def initialize(**args) update!(**args) end |
Instance Attribute Details
#activation_policy ⇒ String
The activation policy specifies when the instance is activated; it is
applicable only when the instance state is 'RUNNABLE'. Valid values: 'ALWAYS':
The instance is on, and remains so even in the absence of connection requests.
NEVER: The instance is off; it is not activated, even if a connection
request arrives.
Corresponds to the JSON property activationPolicy
280 281 282 |
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 280 def activation_policy @activation_policy end |
#auto_storage_increase ⇒ Boolean Also known as: auto_storage_increase?
[default: ON] If you enable this setting, Cloud SQL checks your available
storage every 30 seconds. If the available storage falls below a threshold
size, Cloud SQL automatically adds additional storage capacity. If the
available storage repeatedly falls below the threshold size, Cloud SQL
continues to add storage until it reaches the maximum of 30 TB.
Corresponds to the JSON property autoStorageIncrease
289 290 291 |
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 289 def auto_storage_increase @auto_storage_increase end |
#data_disk_size_gb ⇒ Fixnum
The storage capacity available to the database, in GB. The minimum (and
default) size is 10GB.
Corresponds to the JSON property dataDiskSizeGb
296 297 298 |
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 296 def data_disk_size_gb @data_disk_size_gb end |
#data_disk_type ⇒ String
The type of storage: PD_SSD (default) or PD_HDD.
Corresponds to the JSON property dataDiskType
301 302 303 |
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 301 def data_disk_type @data_disk_type end |
#database_flags ⇒ Hash<String,String>
The database flags passed to the Cloud SQL instance at startup. An object
containing a list of "key": value pairs. Example: "name": "wrench", "mass": "
1.3kg", "count": "3".
Corresponds to the JSON property databaseFlags
308 309 310 |
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 308 def database_flags @database_flags end |
#database_version ⇒ String
The database engine type and version.
Corresponds to the JSON property databaseVersion
313 314 315 |
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 313 def database_version @database_version end |
#ip_config ⇒ Google::Apis::DatamigrationV1beta1::SqlIpConfig
IP Management configuration.
Corresponds to the JSON property ipConfig
318 319 320 |
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 318 def ip_config @ip_config end |
#root_password ⇒ String
Input only. Initial root password.
Corresponds to the JSON property rootPassword
323 324 325 |
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 323 def root_password @root_password end |
#root_password_set ⇒ Boolean Also known as: root_password_set?
Output only. Indicates If this connection profile root password is stored.
Corresponds to the JSON property rootPasswordSet
328 329 330 |
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 328 def root_password_set @root_password_set end |
#source_id ⇒ String
The Database Migration Service source connection profile ID, in the format:
projects/my_project_name/locations/us-central1/connectionProfiles/
connection_profile_ID
Corresponds to the JSON property sourceId
336 337 338 |
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 336 def source_id @source_id end |
#storage_auto_resize_limit ⇒ Fixnum
The maximum size to which storage capacity can be automatically increased. The
default value is 0, which specifies that there is no limit.
Corresponds to the JSON property storageAutoResizeLimit
342 343 344 |
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 342 def storage_auto_resize_limit @storage_auto_resize_limit end |
#tier ⇒ String
The tier (or machine type) for this instance, for example: db-n1-standard-1 (
MySQL instances). For more information, see Cloud SQL Instance Settings.
Corresponds to the JSON property tier
349 350 351 |
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 349 def tier @tier end |
#user_labels ⇒ Hash<String,String>
The resource labels for a Cloud SQL instance to use to annotate any related
underlying resources such as Compute Engine VMs. An object containing a list
of "key": "value" pairs. Example: "name": "wrench", "mass": "18kg", "count":
"3".
Corresponds to the JSON property userLabels
357 358 359 |
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 357 def user_labels @user_labels end |
#zone ⇒ String
The Google Cloud Platform zone where your Cloud SQL database instance is
located.
Corresponds to the JSON property zone
363 364 365 |
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 363 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 |
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 370 def update!(**args) @activation_policy = args[:activation_policy] if args.key?(:activation_policy) @auto_storage_increase = args[:auto_storage_increase] if args.key?(:auto_storage_increase) @data_disk_size_gb = args[:data_disk_size_gb] if args.key?(:data_disk_size_gb) @data_disk_type = args[:data_disk_type] if args.key?(:data_disk_type) @database_flags = args[:database_flags] if args.key?(:database_flags) @database_version = args[:database_version] if args.key?(:database_version) @ip_config = args[:ip_config] if args.key?(:ip_config) @root_password = args[:root_password] if args.key?(:root_password) @root_password_set = args[:root_password_set] if args.key?(:root_password_set) @source_id = args[:source_id] if args.key?(:source_id) @storage_auto_resize_limit = args[:storage_auto_resize_limit] if args.key?(:storage_auto_resize_limit) @tier = args[:tier] if args.key?(:tier) @user_labels = args[:user_labels] if args.key?(:user_labels) @zone = args[:zone] if args.key?(:zone) end |