Class: Google::Apis::DatamigrationV1beta1::MySqlConnectionProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datamigration_v1beta1/classes.rb,
lib/google/apis/datamigration_v1beta1/representations.rb,
lib/google/apis/datamigration_v1beta1/representations.rb

Overview

Specifies connection parameters required specifically for MySQL databases.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MySqlConnectionProfile

Returns a new instance of MySqlConnectionProfile.



1045
1046
1047
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1045

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cloud_sql_idString

If the source is a Cloud SQL database, use this field to provide the Cloud SQL instance ID of the source. Corresponds to the JSON property cloudSqlId

Returns:

  • (String)


1008
1009
1010
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1008

def cloud_sql_id
  @cloud_sql_id
end

#hostString

Required. The IP or hostname of the source MySQL database. Corresponds to the JSON property host

Returns:

  • (String)


1013
1014
1015
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1013

def host
  @host
end

#passwordString

Required. Input only. The password for the user that Database Migration Service will be using to connect to the database. This field is not returned on request, and the value is encrypted when stored in Database Migration Service. Corresponds to the JSON property password

Returns:

  • (String)


1021
1022
1023
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1021

def password
  @password
end

#password_setBoolean Also known as: password_set?

Output only. Indicates If this connection profile password is stored. Corresponds to the JSON property passwordSet

Returns:

  • (Boolean)


1026
1027
1028
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1026

def password_set
  @password_set
end

#portFixnum

Required. The network port of the source MySQL database. Corresponds to the JSON property port

Returns:

  • (Fixnum)


1032
1033
1034
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1032

def port
  @port
end

#sslGoogle::Apis::DatamigrationV1beta1::SslConfig

SSL configuration information. Corresponds to the JSON property ssl



1037
1038
1039
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1037

def ssl
  @ssl
end

#usernameString

Required. The username that Database Migration Service will use to connect to the database. The value is encrypted when stored in Database Migration Service. Corresponds to the JSON property username

Returns:

  • (String)


1043
1044
1045
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1043

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1050
1051
1052
1053
1054
1055
1056
1057
1058
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1050

def update!(**args)
  @cloud_sql_id = args[:cloud_sql_id] if args.key?(:cloud_sql_id)
  @host = args[:host] if args.key?(:host)
  @password = args[:password] if args.key?(:password)
  @password_set = args[:password_set] if args.key?(:password_set)
  @port = args[:port] if args.key?(:port)
  @ssl = args[:ssl] if args.key?(:ssl)
  @username = args[:username] if args.key?(:username)
end