Class: Google::Apis::DatamigrationV1beta1::RetryInfo
- Inherits:
-
Object
- Object
- Google::Apis::DatamigrationV1beta1::RetryInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamigration_v1beta1/classes.rb,
lib/google/apis/datamigration_v1beta1/representations.rb,
lib/google/apis/datamigration_v1beta1/representations.rb
Overview
Describes when the clients can retry a failed request. Clients could ignore
the recommendation here or retry when this information is missing from error
responses. It's always recommended that clients should use exponential backoff
when retrying. Clients should wait until retry_delay amount of time has
passed since receiving the error response before retrying. If retrying
requests also fail, clients should use an exponential backoff scheme to
gradually increase the delay between retries based on retry_delay, until
either a maximum number of retries have been reached or a maximum retry delay
cap has been reached.
Instance Attribute Summary collapse
-
#retry_delay ⇒ String
Clients should wait at least this long between retrying the same request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RetryInfo
constructor
A new instance of RetryInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RetryInfo
Returns a new instance of RetryInfo.
1750 1751 1752 |
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1750 def initialize(**args) update!(**args) end |
Instance Attribute Details
#retry_delay ⇒ String
Clients should wait at least this long between retrying the same request.
Corresponds to the JSON property retryDelay
1748 1749 1750 |
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1748 def retry_delay @retry_delay end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1755 1756 1757 |
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1755 def update!(**args) @retry_delay = args[:retry_delay] if args.key?(:retry_delay) end |