Class: Google::Apis::DatamigrationV1beta1::ReverseSshConnectivity
- Inherits:
-
Object
- Object
- Google::Apis::DatamigrationV1beta1::ReverseSshConnectivity
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamigration_v1beta1/classes.rb,
lib/google/apis/datamigration_v1beta1/representations.rb,
lib/google/apis/datamigration_v1beta1/representations.rb
Overview
The details needed to configure a reverse SSH tunnel between the source and destination databases. These details will be used when calling the generateSshScript method (see https://cloud.google.com/database-migration/docs/ reference/rest/v1beta1/projects.locations.migrationJobs/generateSshScript) to produce the script that will help set up the reverse SSH tunnel, and to set up the VPC peering between the Cloud SQL private network and the VPC.
Instance Attribute Summary collapse
-
#vm ⇒ String
The name of the virtual machine (Compute Engine) used as the bastion server for the SSH tunnel.
-
#vm_ip ⇒ String
Required.
-
#vm_port ⇒ Fixnum
Required.
-
#vpc ⇒ String
The name of the VPC to peer with the Cloud SQL private network.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReverseSshConnectivity
constructor
A new instance of ReverseSshConnectivity.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReverseSshConnectivity
Returns a new instance of ReverseSshConnectivity.
1289 1290 1291 |
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1289 def initialize(**args) update!(**args) end |
Instance Attribute Details
#vm ⇒ String
The name of the virtual machine (Compute Engine) used as the bastion server
for the SSH tunnel.
Corresponds to the JSON property vm
1270 1271 1272 |
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1270 def vm @vm end |
#vm_ip ⇒ String
Required. The IP of the virtual machine (Compute Engine) used as the bastion
server for the SSH tunnel.
Corresponds to the JSON property vmIp
1276 1277 1278 |
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1276 def vm_ip @vm_ip end |
#vm_port ⇒ Fixnum
Required. The forwarding port of the virtual machine (Compute Engine) used as
the bastion server for the SSH tunnel.
Corresponds to the JSON property vmPort
1282 1283 1284 |
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1282 def vm_port @vm_port end |
#vpc ⇒ String
The name of the VPC to peer with the Cloud SQL private network.
Corresponds to the JSON property vpc
1287 1288 1289 |
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1287 def vpc @vpc end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1294 1295 1296 1297 1298 1299 |
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1294 def update!(**args) @vm = args[:vm] if args.key?(:vm) @vm_ip = args[:vm_ip] if args.key?(:vm_ip) @vm_port = args[:vm_port] if args.key?(:vm_port) @vpc = args[:vpc] if args.key?(:vpc) end |