Class: Google::Apis::DatamigrationV1beta1::VmCreationConfig
- Inherits:
-
Object
- Object
- Google::Apis::DatamigrationV1beta1::VmCreationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/datamigration_v1beta1/classes.rb,
lib/google/apis/datamigration_v1beta1/representations.rb,
lib/google/apis/datamigration_v1beta1/representations.rb
Overview
VM creation configuration message
Instance Attribute Summary collapse
-
#subnet ⇒ String
The subnet name the vm needs to be created in.
-
#vm_machine_type ⇒ String
Required.
-
#vm_zone ⇒ String
The Google Cloud Platform zone to create the VM in.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VmCreationConfig
constructor
A new instance of VmCreationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VmCreationConfig
Returns a new instance of VmCreationConfig.
1653 1654 1655 |
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1653 def initialize(**args) update!(**args) end |
Instance Attribute Details
#subnet ⇒ String
The subnet name the vm needs to be created in.
Corresponds to the JSON property subnet
1641 1642 1643 |
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1641 def subnet @subnet end |
#vm_machine_type ⇒ String
Required. VM instance machine type to create.
Corresponds to the JSON property vmMachineType
1646 1647 1648 |
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1646 def vm_machine_type @vm_machine_type end |
#vm_zone ⇒ String
The Google Cloud Platform zone to create the VM in.
Corresponds to the JSON property vmZone
1651 1652 1653 |
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1651 def vm_zone @vm_zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1658 1659 1660 1661 1662 |
# File 'lib/google/apis/datamigration_v1beta1/classes.rb', line 1658 def update!(**args) @subnet = args[:subnet] if args.key?(:subnet) @vm_machine_type = args[:vm_machine_type] if args.key?(:vm_machine_type) @vm_zone = args[:vm_zone] if args.key?(:vm_zone) end |